pub struct GoogleCloudRetailV2BatchUpdateGenerativeQuestionConfigsResponse {
pub generative_question_configs: Option<Vec<GoogleCloudRetailV2GenerativeQuestionConfig>>,
}Expand description
Aggregated response for UpdateGenerativeQuestionConfig method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
generative_question_configs: Option<Vec<GoogleCloudRetailV2GenerativeQuestionConfig>>Optional. The updates question configs.